@@ -1,23 +1,22 @@
 package Sweet::Dir;
+use latest;
 use Moose;
-use namespace::autoclean;
+
+use Sweet::Types;
 
 use Carp;
-use Try::Tiny;
-
-use MooseX::Types::Path::Class;
 use File::Path qw(make_path remove_tree);
-use File::Slurp::Tiny qw(read_dir);
+use MooseX::AttributeShortcuts;
+use MooseX::Types::Path::Class;
+use Sweet::File;
 use Try::Tiny;
 
-use Sweet::File;
+use namespace::autoclean;
 
 has path => (
-    builder => '_build_path',
     coerce  => 1,
-    is      => 'ro',
+    is      => 'lazy',
     isa     => 'Path::Class::Dir',
-    lazy    => 1,
 );
 
 sub create {
@@ -33,7 +32,7 @@ sub create {
       make_path( $path, { error => \$make_path_error } );
     }
     catch {
-      confess $make_path_error;
+      croack $make_path_error;
     };
 }
 
@@ -49,7 +48,7 @@ sub erase {
       remove_path( $path, { error => \$remove_path_error } );
     }
     catch {
-      confess $remove_path_error;
+      croack $remove_path_error;
     };
 }
 
@@ -73,7 +72,7 @@ sub file {
         $builder->( $self, $name );
     }
     catch {
-        confess $_;
+        croak $_;
     };
 
     return $file;
@@ -82,11 +81,15 @@ sub file {
 sub file_list {
     my ( $self, $regexp ) = @_;
 
-    my @files = read_dir( $self->path );
+    my $path = $self->path;
 
-    return @files if not defined $regexp;
+    opendir my ($dir), $path or croak "Could not open $path: $!";
+    my @file_names = grep { not m/ ^ \.\.? $ /x } readdir $dir;
+    closedir $dir;
 
-    return grep { m/$regexp/ } @files;
+    return @file_names if not defined $regexp;
+
+    return grep { m/$regexp/ } @file_names;
 }
 
 sub is_a_directory { -d shift->path }
@@ -110,12 +113,10 @@ sub sub_dir {
     return $sub_dir;
 }
 
-use overload q("") => sub { shift->path };
+use overload q("") => sub { shift->path }, bool => sub { 1 }, fallback => 1;
 
 __PACKAGE__->meta->make_immutable;
 
-1;
-
 __END__
 
 =head1 NAME
@@ -129,7 +130,6 @@ Sweet::Dir
     my $dir = Sweet::Dir->new(path => '/path/to/dir');
     $dir->create;
 
-
     say $dir; # /path/to/dir
 
 =head1 ATTRIBUTES
