@@ -1,4 +1,5 @@
 package Sweet::File::CSV;
+use latest;
 use Moose;
 use namespace::autoclean;
 
@@ -16,7 +17,9 @@ Sweet::File::CSV
 
 =head1 SYNOPSIS
 
-    my $csv = Sweet::File::CSV->new(dir => $dir, name => 'file.csv');
+    my $csv = Sweet::File::CSV->new(
+      path => '/path/to/file.csv'
+    );
 
 =head1 INHERITANCE
 
